@@ -6,6 +6,6 @@ from datetime import datetime as sj
 from time import sleep as dd
 from math import pi as pai1
 from sys import exit as tc
-#from pdsystem import * #The moudle of Maker:神秘的·  ps:需要pip下载,在终端输入pip install pdsystem
-#pdios()
+from pdsystem import * #The moudle of Maker:神秘的·  ps:需要pip下载,在终端输入pip install pdsystem
+pdios()
 start=sj.now()
